@@ -6,7 +6,7 @@ use Class::Inspector ();
 use Scalar::Util ();
 use MRO::Compat;
 
-our $VERSION = '0.08001';
+our $VERSION = '0.08002';
 
 =head1 NAME
 
@@ -243,8 +243,6 @@ name passed as an argument.
 =cut
 
 sub get_simple {
-    my ($self, $get) = @_;
-  return $self->{$get};
   return $_[0]->{$_[1]};
 }
 
@@ -363,9 +361,9 @@ Returns: $value
 Gets the value of the specified component class.
 
     __PACKAGE__->mk_group_accessors('component_class' => 'result_class');
-    
+
     $self->result_class->method();
-    
+
     ## same as
     $self->get_component_class('result_class')->method();
 
@@ -390,7 +388,7 @@ it. This method will die if the specified class could not be loaded.
 
     __PACKAGE__->mk_group_accessors('component_class' => 'result_class');
     __PACKAGE__->result_class('MyClass');
-    
+
     $self->result_class->method();
 
 =cut
